Crate boundless_market

Crate boundless_market 

Boundless Market SDK

Boundless is the first universal ZK protocol that transforms how developers build with zero-knowledge proofs across any chain. Core to Boundless is a decentralized proof market. Competitive proving services ensure reliable delivery, liveness, and best-in-class pricing.

This crate is the SDK for interacting with the Boundless Market.

For more information about using Boundless, see docs.boundless.network.

Re-exports

pub use client::Client;Non-target_os=zkvm
pub use client::StandardClient;Non-target_os=zkvm
pub use contracts::boundless_market::BoundlessMarketService;Non-target_os=zkvm
pub use contracts::Offer;
pub use contracts::ProofRequest;
pub use contracts::RequestId;
pub use contracts::RequestInput;
pub use contracts::Requirements;
pub use deployments::Deployment;Non-target_os=zkvm
pub use input::GuestEnv;Non-target_os=zkvm
pub use input::GuestEnvBuilder;Non-target_os=zkvm
pub use order_stream_client::OrderStreamClient;Non-target_os=zkvm
pub use request_builder::ParameterizationMode;Non-target_os=zkvm
pub use storage::StandardDownloader;Non-target_os=zkvm
pub use storage::StandardUploader;Non-target_os=zkvm
pub use storage::StorageDownloaderConfig;Non-target_os=zkvm
pub use storage::StorageUploaderConfig;Non-target_os=zkvm
pub use alloy;Non-target_os=zkvm

Modules

balance_alerts_layerNon-target_os=zkvm
A ProviderLayer module.
blake3_groth16blake3-groth16 and non-target_os=zkvm
Module providing blake3-groth16 related integrations.
clientNon-target_os=zkvm
Client module for interacting with the Boundless Market API.
contracts
Contracts module for interacting with the Boundless Market smart contracts.
deploymentsNon-target_os=zkvm
Configs for deployments of the Boundless Market (e.g. contract addresses, URLs, etc).
dynamic_gas_fillerNon-target_os=zkvm
Dynamic gas filler module.
indexer_clientNon-target_os=zkvm
Client module for interacting with the Boundless Indexer API. Client for interacting with the Boundless Indexer API to fetch market price aggregates.
inputNon-target_os=zkvm
Input module for serializing input.
nonce_layerNon-target_os=zkvm
A ProviderLayer module for managing nonces with semaphores.
order_stream_clientNon-target_os=zkvm
Order stream client module for submitting requests off-chain.
price_providerNon-target_os=zkvm
Module providing market pricing functionality.
prover_utilsprover_utils and non-target_os=zkvm
Order pricing helpers and prover utilities.
request_builderNon-target_os=zkvm
Module providing functionality to build requests.
selectorNon-target_os=zkvm
Selector module implementing utility functions for supported selectors. Selector utility functions.
storageNon-target_os=zkvm
Storage module for interacting with the storage uploader. Storage module for uploading and downloading programs and inputs.
test_helperstest-utils and non-target_os=zkvm
Test helpers for testing the Boundless Market.

Enums

NotProvided
Type used in the Client and StandardRequestBuilder to indicate that the component in question is not provided.

Constants

LARGE_REQUESTOR_LIST_THRESHOLD_KHZ
Peak performance thresholds for enabling requestor lists (kHz) for large requests.
XL_REQUESTOR_LIST_THRESHOLD_KHZ
Peak performance thresholds for enabling requestor lists (kHz) for XL requests.