StandardClient

Type Alias StandardClient 

pub type StandardClient = Client<DynProvider, StandardUploader, StandardDownloader, StandardRequestBuilder<DynProvider, StandardUploader, StandardDownloader>, PrivateKeySigner>;
Available on non-target_os=zkvm only.
Alias for a Client instantiated with the standard implementations provided by this crate.

Aliased Type

pub struct StandardClient {
    pub boundless_market: BoundlessMarketService<DynProvider>,
    pub set_verifier: SetVerifierService<DynProvider>,
    pub uploader: Option<StandardUploader>,
    pub downloader: StandardDownloader,
    pub offchain_client: Option<OrderStreamClient>,
    pub signer: Option<LocalSigner<SigningKey<Secp256k1>>>,
    pub request_builder: Option<StandardRequestBuilder>,
    pub deployment: Deployment,
    pub funding_mode: FundingMode,
}

Fields

boundless_market: BoundlessMarketService<DynProvider>

Boundless market service.

set_verifier: SetVerifierService<DynProvider>

Set verifier service.

uploader: Option<StandardUploader>

StandardUploader to upload programs and inputs.

If not provided, this client will not be able to upload programs or inputs.

downloader: StandardDownloader

Downloader for fetching data from storage.

offchain_client: Option<OrderStreamClient>

OrderStreamClient to submit requests off-chain.

If not provided, requests not only be sent onchain via a transaction.

signer: Option<LocalSigner<SigningKey<Secp256k1>>>

Alloy Signer for signing requests.

If not provided, requests must be pre-signed handing them to this client.

request_builder: Option<StandardRequestBuilder>

RequestBuilder to construct ProofRequest.

If not provided, requests must be fully constructed before handing them to this client.

deployment: Deployment

Deployment of Boundless that this client is connected to.

funding_mode: FundingMode

Funding mode for onchain requests.

Defaults to FundingMode::Always. FundingMode::Never can be used to never send value with the request. FundingMode::AvailableBalance can be used to only send value if the current onchain balance is insufficient. FundingMode::BelowThreshold can be used to send value only if the balance is below a configurable threshold. FundingMode::MinMaxBalance can be used to maintain a minimum balance by funding requests accordingly.