deploy

Function deploy 

pub fn deploy<P: Provider<N>, N: Network>(
    __provider: P,
    verifier: Address,
    boundlessMarket: Address,
    imageId: FixedBytes<32>,
    _targetGas: U256,
) -> impl Future<Output = Result<MockCallbackInstance<P, N>>>
Available on crate feature test-utils only.
Deploys this contract using the given provider and constructor arguments, if any.

Returns a new instance of the contract, if the deployment was successful.

For more fine-grained control over the deployment process, use deploy_builder instead.