#[non_exhaustive]pub enum Predicate {
DigestMatch(Digest, Digest),
PrefixMatch(Digest, Bytes),
ClaimDigestMatch(Digest),
}Expand description
A Predicate is a function over the claim that determines whether it meets the clients requirements.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DigestMatch(Digest, Digest)
The image id and digest must match the provided image id and journal digest.
PrefixMatch(Digest, Bytes)
The image id and journal prefix must match the provided image id and journal.
ClaimDigestMatch(Digest)
The claim digest must match the provided claim digest.
Implementations
Sourceimpl Predicate
impl Predicate
Sourcepub fn digest_match(
image_id: impl Into<Digest>,
journal_digest: impl Into<Digest>,
) -> Self
pub fn digest_match( image_id: impl Into<Digest>, journal_digest: impl Into<Digest>, ) -> Self
Returns a predicate to match the journal digest. This ensures that the request’s fulfillment will contain a journal with the same digest.
Sourcepub fn prefix_match(
image_id: impl Into<Digest>,
journal_prefix: impl Into<Bytes>,
) -> Self
pub fn prefix_match( image_id: impl Into<Digest>, journal_prefix: impl Into<Bytes>, ) -> Self
Returns a predicate to match the journal prefix. This ensures that the request’s fulfillment will contain a journal with the same prefix.
Sourcepub fn claim_digest_match(claim_digest: impl Into<Digest>) -> Self
pub fn claim_digest_match(claim_digest: impl Into<Digest>) -> Self
Returns a predicate to match the claim digest. This ensures that the request’s fulfillment will contain a claim with the same digest.
Sourcepub fn eval(&self, fulfillment_data: &FulfillmentData) -> Option<Digest>
pub fn eval(&self, fulfillment_data: &FulfillmentData) -> Option<Digest>
Evaluates the predicate against the fulfillment data, returning the claim digest if the
evaluation succeeds or None if it fails.