#[non_exhaustive]pub enum RequestError {
Show 22 variants
MalformedRequestId,
ClientAddrIsZero,
SignatureError(Error),
SignatureNonCanonicalError,
EmptyImageUrl,
MalformedImageUrl(ParseError),
ImageIdIsZero,
OfferTimeoutIsZero,
OfferLockTimeoutIsZero,
OfferRampUpGreaterThanLockTimeout,
OfferLockTimeoutGreaterThanTimeout,
OfferTimeoutRangeTooLarge,
OfferMaxPriceIsZero,
OfferMaxPriceIsLessThanMin,
OfferRampUpStartIsZero,
MissingRequirements,
MissingImageUrl,
MissingInput,
MissingOffer,
MissingRequestId,
DigestMismatch,
PredicateError(PredicateError),
}Expand description
Errors that can occur when creating a proof request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
MalformedRequestId
The request ID is malformed.
ClientAddrIsZero
The client address is all zeroes.
SignatureError(Error)
target_os=zkvm only.The signature is invalid.
SignatureNonCanonicalError
Signature is non-canonical.
EmptyImageUrl
The image URL is empty.
MalformedImageUrl(ParseError)
The image URL is malformed.
ImageIdIsZero
The image ID is zero.
OfferTimeoutIsZero
The offer timeout is zero.
OfferLockTimeoutIsZero
The offer lock timeout is zero.
OfferRampUpGreaterThanLockTimeout
The offer ramp up period is longer than the lock timeout
OfferLockTimeoutGreaterThanTimeout
The offer lock timeout is greater than the timeout
OfferTimeoutRangeTooLarge
Difference between timeout and lockTimeout much be less than 2^24
This is a requirement of the BoundlessMarket smart to optimize use of storage.
OfferMaxPriceIsZero
The offer max price is zero.
OfferMaxPriceIsLessThanMin
The offer max price is less than the min price.
OfferRampUpStartIsZero
The offer ramp-up start is zero.
MissingRequirements
The requirements are missing from the request.
MissingImageUrl
The image URL is missing from the request.
MissingInput
The input is missing from the request.
MissingOffer
The offer is missing from the request.
MissingRequestId
The request ID is missing from the request.
DigestMismatch
Request digest mismatch.
PredicateError(PredicateError)
Predicate related errors