#[non_exhaustive]pub struct Deployment {
pub market_chain_id: Option<u64>,
pub boundless_market_address: Address,
pub verifier_router_address: Option<Address>,
pub set_verifier_address: Address,
pub collateral_token_address: Option<Address>,
pub order_stream_url: Option<Cow<'static, str>>,
pub deployment_block: Option<u64>,
pub indexer_url: Option<Cow<'static, str>>,
}target_os=zkvm only.Expand description
Configuration for a deployment of the Boundless Market.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.market_chain_id: Option<u64>EIP-155 chain ID of the network.
boundless_market_address: AddressAddress of the BoundlessMarket contract.
verifier_router_address: Option<Address>Address of the RiscZeroVerifierRouter contract.
The verifier router implements IRiscZeroVerifier. Each network has a canonical router, that is deployed by the core team. You can additionally deploy and manage your own verifier instead. See the Boundless docs for more details.
set_verifier_address: AddressAddress of the RiscZeroSetVerifier contract.
collateral_token_address: Option<Address>Address of the collateral token contract. The collateral token is an ERC-20.
order_stream_url: Option<Cow<'static, str>>URL for the offchain order stream service.
deployment_block: Option<u64>Block number when the BoundlessMarket contract was deployed. Used as a starting point for event queries.
indexer_url: Option<Cow<'static, str>>Indexer URL for the market.
Implementations
Sourceimpl Deployment
impl Deployment
Sourcepub fn builder() -> DeploymentBuilder
pub fn builder() -> DeploymentBuilder
Create a new DeploymentBuilder.
Sourcepub const fn from_chain(chain: NamedChain) -> Option<Deployment>
pub const fn from_chain(chain: NamedChain) -> Option<Deployment>
Lookup the Deployment for a named chain.
Sourcepub fn from_chain_id(chain_id: impl Into<u64>) -> Option<Deployment>
pub fn from_chain_id(chain_id: impl Into<u64>) -> Option<Deployment>
Lookup the Deployment by chain ID.
Sourcepub fn collateral_token_supports_permit(&self) -> bool
pub fn collateral_token_supports_permit(&self) -> bool
Check if the collateral token supports permit. Some chain’s bridged tokens do not support permit, for example Base.