pub enum NotProvided {}Expand description
Type used in the Client and StandardRequestBuilder to indicate that the component in question is not provided.
Note that this in an uninhabited type and cannot be instantiated. When used as
Option<NotProvided>, the only possible variant for this option is None.