#[non_exhaustive]pub struct OfferLayerConfig {Show 13 fields
pub parameterization_mode: Option<ParameterizationMode>,
pub min_price_per_cycle: Option<U256>,
pub max_price_per_cycle: Option<U256>,
pub bidding_start_delay: Option<u64>,
pub ramp_up_period: Option<u32>,
pub lock_timeout: Option<u32>,
pub timeout: Option<u32>,
pub lock_collateral: Option<U256>,
pub lock_gas_estimate: u64,
pub fulfill_gas_estimate: u64,
pub groth16_verify_gas_estimate: u64,
pub smart_contract_sig_verify_gas_estimate: u64,
pub supported_selectors: SupportedSelectors,
}target_os=zkvm only.Expand description
Configuration for the OfferLayer.
Defines the default pricing parameters, timeouts, gas estimates, and other settings used when constructing offers for proof requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameterization_mode: Option<ParameterizationMode>Parameterization mode.
Defines the offering parameters for the request. The default is ParameterizationMode::fulfillment(), which is a conservative mode that ensures more provers can fulfill the request.
Example
OfferLayerConfig::builder().parameterization_mode(ParameterizationMode::fulfillment());min_price_per_cycle: Option<U256>Minimum price per RISC Zero execution cycle, in wei.
max_price_per_cycle: Option<U256>Maximum price per RISC Zero execution cycle, in wei.
bidding_start_delay: Option<u64>Time in seconds to delay the start of bidding after request creation.
ramp_up_period: Option<u32>Duration in seconds for the price to ramp up from min to max.
lock_timeout: Option<u32>Time in seconds that a prover has to fulfill a locked request.
timeout: Option<u32>Maximum time in seconds that a request can remain active.
lock_collateral: Option<U256>Lock collateral
lock_gas_estimate: u64Estimated gas used when locking a request.
fulfill_gas_estimate: u64Estimated gas used when fulfilling a request.
groth16_verify_gas_estimate: u64Estimated gas used for Groth16 verification.
smart_contract_sig_verify_gas_estimate: u64Estimated gas used for ERC-1271 signature verification.
supported_selectors: SupportedSelectorsSupported proof types and their corresponding selectors.
Implementations
Sourceimpl OfferLayerConfig
impl OfferLayerConfig
Sourcepub fn builder() -> OfferLayerConfigBuilder
pub fn builder() -> OfferLayerConfigBuilder
Creates a new builder for constructing an OfferLayerConfig.
This provides a way to customize pricing parameters, timeouts, and other offer-related settings used when generating proof requests.