pub struct OfferLayerConfigBuilder { /* private fields */ }target_os=zkvm only.Expand description
Builder for OfferLayerConfig.
Implementations
Sourceimpl OfferLayerConfigBuilder
impl OfferLayerConfigBuilder
Sourcepub fn parameterization_mode<VALUE: Into<Option<ParameterizationMode>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn parameterization_mode<VALUE: Into<Option<ParameterizationMode>>>( &mut self, value: VALUE, ) -> &mut Self
Parameterization mode.
Defines the offering parameters for the request. The default is ParameterizationMode::fulfillment(), which is a conservative mode that ensures more provers can fulfill the request.
Example
OfferLayerConfig::builder().parameterization_mode(ParameterizationMode::fulfillment());Sourcepub fn min_price_per_cycle<VALUE: Into<U256>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn min_price_per_cycle<VALUE: Into<U256>>( &mut self, value: VALUE, ) -> &mut Self
Minimum price per RISC Zero execution cycle, in wei.
Sourcepub fn max_price_per_cycle<VALUE: Into<U256>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn max_price_per_cycle<VALUE: Into<U256>>( &mut self, value: VALUE, ) -> &mut Self
Maximum price per RISC Zero execution cycle, in wei.
Sourcepub fn bidding_start_delay(&mut self, value: u64) -> &mut Self
pub fn bidding_start_delay(&mut self, value: u64) -> &mut Self
Time in seconds to delay the start of bidding after request creation.
Sourcepub fn ramp_up_period(&mut self, value: u32) -> &mut Self
pub fn ramp_up_period(&mut self, value: u32) -> &mut Self
Duration in seconds for the price to ramp up from min to max.
Sourcepub fn lock_timeout(&mut self, value: u32) -> &mut Self
pub fn lock_timeout(&mut self, value: u32) -> &mut Self
Time in seconds that a prover has to fulfill a locked request.
Sourcepub fn timeout(&mut self, value: u32) -> &mut Self
pub fn timeout(&mut self, value: u32) -> &mut Self
Maximum time in seconds that a request can remain active.
Sourcepub fn lock_collateral<VALUE: Into<U256>>(&mut self, value: VALUE) -> &mut Self
pub fn lock_collateral<VALUE: Into<U256>>(&mut self, value: VALUE) -> &mut Self
Lock collateral
Sourcepub fn lock_gas_estimate(&mut self, value: u64) -> &mut Self
pub fn lock_gas_estimate(&mut self, value: u64) -> &mut Self
Estimated gas used when locking a request.
Sourcepub fn fulfill_gas_estimate(&mut self, value: u64) -> &mut Self
pub fn fulfill_gas_estimate(&mut self, value: u64) -> &mut Self
Estimated gas used when fulfilling a request.
Sourcepub fn groth16_verify_gas_estimate(&mut self, value: u64) -> &mut Self
pub fn groth16_verify_gas_estimate(&mut self, value: u64) -> &mut Self
Estimated gas used for Groth16 verification.
Sourcepub fn smart_contract_sig_verify_gas_estimate(
&mut self,
value: u64,
) -> &mut Self
pub fn smart_contract_sig_verify_gas_estimate( &mut self, value: u64, ) -> &mut Self
Estimated gas used for ERC-1271 signature verification.
Sourcepub fn supported_selectors<VALUE: Into<SupportedSelectors>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn supported_selectors<VALUE: Into<SupportedSelectors>>( &mut self, value: VALUE, ) -> &mut Self
Supported proof types and their corresponding selectors.
Sourcepub fn build(&self) -> Result<OfferLayerConfig, OfferLayerConfigBuilderError>
pub fn build(&self) -> Result<OfferLayerConfig, OfferLayerConfigBuilderError>