OfferParams

Struct OfferParams 

#[non_exhaustive]
pub struct OfferParams { pub min_price: Option<U256>, pub max_price: Option<U256>, pub bidding_start: Option<u64>, pub ramp_up_period: Option<u32>, pub lock_timeout: Option<u32>, pub timeout: Option<u32>, pub lock_collateral: Option<U256>, }
Available on non-target_os=zkvm only.
A partial Offer, with all the fields as optional. Used in the OfferLayer to override defaults set in the OfferLayerConfig.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
min_price: Option<U256>

Minimum price willing to pay for the proof, in wei.

max_price: Option<U256>

Maximum price willing to pay for the proof, in wei.

bidding_start: Option<u64>

Timestamp when bidding will start for this request.

ramp_up_period: Option<u32>

Duration in seconds for the price to ramp up from min to max.

lock_timeout: Option<u32>

Time in seconds that a prover has to fulfill a locked request.

timeout: Option<u32>

Maximum time in seconds that a request can remain active.

lock_collateral: Option<U256>

Amount of the stake token that the prover must stake when locking a request.

Implementations

Source

impl OfferParams

pub fn builder() -> OfferParamsBuilder

Creates a new builder for constructing OfferParams.

Use this to set specific pricing parameters, timeouts, or other offer details that will override the defaults from OfferLayerConfig.