StorageLayer

Struct StorageLayer 

#[non_exhaustive]
pub struct StorageLayer<U = StandardUploader> { pub uploader: Option<U>, pub config: StorageLayerConfig, }
Available on non-target_os=zkvm only.
A layer responsible for storing programs and inputs.

This layer handles the preparation of program and input data for the proof request. It can upload large programs and inputs to external storage, or include smaller inputs directly in the request as inline data.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
uploader: Option<U>

StorageUploader used to upload programs and inputs.

If not provided, the layer cannot upload files and provided inputs must be no larger than StorageLayerConfig::inline_input_max_bytes.

config: StorageLayerConfig

Configuration controlling storage behavior.

Implementations

Source

impl<S> StorageLayer<S>
where S: StorageUploader,

pub async fn process_program(&self, program: &[u8]) -> Result<Url>

Uploads a program binary and returns its URL.

This method requires a configured storage uploader and will return an error if none is available.

pub async fn process_env(&self, env: &GuestEnv) -> Result<RequestInput>

Processes a guest environment into a RequestInput.

Small inputs (as determined by configuration) will be included inline in the request. Larger inputs will be uploaded to external storage, requiring a configured storage uploader.

Source

impl<S> StorageLayer<S>

pub fn new(uploader: Option<S>, config: StorageLayerConfig) -> Self

Creates a new StorageLayer with the given provider and configuration.

The storage uploader is used to upload programs and inputs to external storage.