#[non_exhaustive]pub struct StorageLayerConfig {
pub inline_input_max_bytes: Option<usize>,
}Available on non-
target_os=zkvm only.Expand description
Configuration for the StorageLayer.
Controls how programs and inputs are handled during request building.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inline_input_max_bytes: Option<usize>Maximum number of bytes to send as an inline input.
Inputs larger than this size will be uploaded using the given storage uploader. Set to none to indicate that inputs should always be sent inline.
Implementations
Sourceimpl StorageLayerConfig
impl StorageLayerConfig
Sourcepub fn builder() -> StorageLayerConfigBuilder
pub fn builder() -> StorageLayerConfigBuilder
Creates a new builder for constructing a StorageLayerConfig.
This provides a way to customize storage behavior, such as the maximum size for inline inputs.