pub struct FileStorageUploader { /* private fields */ }Available on non-
target_os=zkvm only.Expand description
Storage uploader that stores files locally.
This provider can be used for:
- Uploading: Stores files in a temporary directory and returns
file://URLs. - Downloading: Reads files from
file://URLs.
Security Note
The file:// scheme should only be enabled in development mode, as it allows
reading arbitrary files from the filesystem.
Implementations
Sourceimpl FileStorageUploader
impl FileStorageUploader
Sourcepub fn new() -> Result<Self, StorageError>
pub fn new() -> Result<Self, StorageError>
Creates a new file storage uploader with a temporary directory.
Sourcepub fn with_path(path: impl AsRef<Path>) -> Result<Self, StorageError>
pub fn with_path(path: impl AsRef<Path>) -> Result<Self, StorageError>
Creates a new file storage uploader with a temporary directory under the given path.
Sourcepub fn from_config(config: &StorageUploaderConfig) -> Result<Self, StorageError>
pub fn from_config(config: &StorageUploaderConfig) -> Result<Self, StorageError>
Creates a new file storage uploader from upload configuration.