Boundless Market SDK
Boundless is the first universal ZK protocol that transforms how developers build with zero-knowledge proofs across any chain. Core to Boundless is a decentralized proof market. Competitive proving services ensure reliable delivery, liveness, and best-in-class pricing.
This crate is the SDK for interacting with the Boundless Market.
For more information about using Boundless, see docs.boundless.network.
Re-exports
pub use client::Client;Non- target_os=zkvmpub use client::StandardClient;Non- target_os=zkvmpub use contracts::boundless_market::BoundlessMarketService;Non- target_os=zkvmpub use contracts::Offer;pub use contracts::ProofRequest;pub use contracts::RequestId;pub use contracts::RequestInput;pub use contracts::Requirements;pub use deployments::Deployment;Non- target_os=zkvmpub use input::GuestEnv;Non- target_os=zkvmpub use input::GuestEnvBuilder;Non- target_os=zkvmpub use order_stream_client::OrderStreamClient;Non- target_os=zkvmpub use request_builder::ParameterizationMode;Non- target_os=zkvmpub use storage::StandardDownloader;Non- target_os=zkvmpub use storage::StandardUploader;Non- target_os=zkvmpub use storage::StorageDownloaderConfig;Non- target_os=zkvmpub use storage::StorageUploaderConfig;Non- target_os=zkvmpub use alloy;Non- target_os=zkvm
Modules
- balance_
alerts_ layer Non- target_os=zkvm - A ProviderLayer module.
- blake3_
groth16 blake3-groth16and non-target_os=zkvm - Module providing blake3-groth16 related integrations.
- client
Non- target_os=zkvm - Client module for interacting with the Boundless Market API.
- contracts
- Contracts module for interacting with the Boundless Market smart contracts.
- deployments
Non- target_os=zkvm - Configs for deployments of the Boundless Market (e.g. contract addresses, URLs, etc).
- dynamic_
gas_ filler Non- target_os=zkvm - Dynamic gas filler module.
- indexer_
client Non- target_os=zkvm - Client module for interacting with the Boundless Indexer API. Client for interacting with the Boundless Indexer API to fetch market price aggregates.
- input
Non- target_os=zkvm - Input module for serializing input.
- nonce_
layer Non- target_os=zkvm - A ProviderLayer module for managing nonces with semaphores.
- order_
stream_ client Non- target_os=zkvm - Order stream client module for submitting requests off-chain.
- price_
provider Non- target_os=zkvm - Module providing market pricing functionality.
- prover_
utils prover_utilsand non-target_os=zkvm - Order pricing helpers and prover utilities.
- request_
builder Non- target_os=zkvm - Module providing functionality to build requests.
- selector
Non- target_os=zkvm - Selector module implementing utility functions for supported selectors. Selector utility functions.
- storage
Non- target_os=zkvm - Storage module for interacting with the storage uploader. Storage module for uploading and downloading programs and inputs.
- test_
helpers test-utilsand non-target_os=zkvm - Test helpers for testing the Boundless Market.
Enums
- NotProvided
- Type used in the Client and StandardRequestBuilder to indicate that the component in question is not provided.
Constants
- LARGE_
REQUESTOR_ LIST_ THRESHOLD_ KHZ - Peak performance thresholds for enabling requestor lists (kHz) for large requests.
- XL_
REQUESTOR_ LIST_ THRESHOLD_ KHZ - Peak performance thresholds for enabling requestor lists (kHz) for XL requests.