pub struct ClientBuilder<U, D, S> {
pub offer_layer_config: OfferLayerConfigBuilder,
pub storage_layer_config: StorageLayerConfigBuilder,
pub request_id_layer_config: RequestIdLayerConfigBuilder,
pub request_finalizer_config: FinalizerConfigBuilder,
pub funding_mode: FundingMode,
pub skip_preflight: Option<bool>,
/* private fields */
}target_os=zkvm only.Expand description
Builder for the Client with standard implementations for the required components.
Fields
offer_layer_config: OfferLayerConfigBuilderConfiguration builder for OfferLayer, part of StandardRequestBuilder.
storage_layer_config: StorageLayerConfigBuilderConfiguration builder for StorageLayer, part of StandardRequestBuilder.
request_id_layer_config: RequestIdLayerConfigBuilderConfiguration builder for RequestIdLayer, part of StandardRequestBuilder.
request_finalizer_config: FinalizerConfigBuilderConfiguration builder for Finalizer, part of StandardRequestBuilder.
funding_mode: FundingModeFunding mode for onchain requests.
Defaults to FundingMode::Always. FundingMode::Never can be used to never send value with the request. FundingMode::AvailableBalance can be used to only send value if the current onchain balance is insufficient. FundingMode::BelowThreshold can be used to send value only if the balance is below a configurable threshold. FundingMode::MinMaxBalance can be used to maintain a minimum balance by funding requests accordingly.
skip_preflight: Option<bool>Whether to skip preflight/pricing checks.
If Some(true), preflight checks are skipped.
If Some(false), preflight checks are run.
If None, falls back to checking the BOUNDLESS_IGNORE_PREFLIGHT environment variable.
Implementations
Sourceimpl<U, S> ClientBuilder<U, NotProvided, S>
impl<U, S> ClientBuilder<U, NotProvided, S>
Sourcepub async fn build(
self,
) -> Result<Client<DynProvider, U, StandardDownloader, StandardRequestBuilder<DynProvider, U, StandardDownloader>, S>>
pub async fn build( self, ) -> Result<Client<DynProvider, U, StandardDownloader, StandardRequestBuilder<DynProvider, U, StandardDownloader>, S>>
Build the client with the StandardDownloader.
Sourceimpl<U, D: StorageDownloader, S> ClientBuilder<U, D, S>
impl<U, D: StorageDownloader, S> ClientBuilder<U, D, S>
Sourcepub async fn build(
self,
) -> Result<Client<DynProvider, U, D, StandardRequestBuilder<DynProvider, U, D>, S>>
pub async fn build( self, ) -> Result<Client<DynProvider, U, D, StandardRequestBuilder<DynProvider, U, D>, S>>
Build the client.
Sourceimpl<U, D, S> ClientBuilder<U, D, S>
impl<U, D, S> ClientBuilder<U, D, S>
Sourcepub fn with_deployment(self, deployment: impl Into<Option<Deployment>>) -> Self
pub fn with_deployment(self, deployment: impl Into<Option<Deployment>>) -> Self
Set the Deployment of the Boundless Market that this client will use.
If None, the builder will attempt to infer the deployment from the chain ID.
Sourcepub fn with_rpc_url(self, rpc_url: Url) -> Self
pub fn with_rpc_url(self, rpc_url: Url) -> Self
Set the RPC URL
Sourcepub fn with_funding_mode(self, funding_mode: FundingMode) -> Self
pub fn with_funding_mode(self, funding_mode: FundingMode) -> Self
Set the funding mode for onchain requests.
Sourcepub fn with_parameterization_mode(
self,
parameterization_mode: ParameterizationMode,
) -> Self
pub fn with_parameterization_mode( self, parameterization_mode: ParameterizationMode, ) -> Self
Set the parameterization mode for the offer layer.
The parameterization mode is used to define the offering parameters for the request. The default is ParameterizationMode::fulfillment(), which is conservative and ensures more provers can fulfill the request.
Example
use boundless_market::request_builder::ParameterizationMode;
Client::builder().with_parameterization_mode(ParameterizationMode::fulfillment());Sourcepub fn with_rpc_urls(self, rpc_urls: Vec<Url>) -> Self
pub fn with_rpc_urls(self, rpc_urls: Vec<Url>) -> Self
Set additional RPC URLs for automatic failover.
When multiple URLs are provided (via with_rpc_url and/or with_rpc_urls),
they are merged into a single list. If 2+ URLs are provided, the client will
use Alloy’s FallbackLayer to distribute requests across multiple RPC endpoints
with automatic failover. If only 1 URL is provided, a regular provider is used.
Example
// Multiple URLs - uses fallback provider
Client::builder()
.with_rpc_urls(vec![
Url::parse("https://rpc2.example.com").unwrap(),
Url::parse("https://rpc3.example.com").unwrap(),
]);
// Single URL - uses regular provider
Client::builder()
.with_rpc_urls(vec![Url::parse("https://rpc.example.com").unwrap()]);Sourcepub fn with_private_key(
self,
private_key: impl Into<PrivateKeySigner>,
) -> ClientBuilder<U, D, PrivateKeySigner>
pub fn with_private_key( self, private_key: impl Into<PrivateKeySigner>, ) -> ClientBuilder<U, D, PrivateKeySigner>
Set the signer from the given private key.
use alloy::signers::local::PrivateKeySigner;
Client::builder().with_private_key(PrivateKeySigner::random());Sourcepub fn with_private_key_str(
self,
private_key: impl AsRef<str>,
) -> Result<ClientBuilder<U, D, PrivateKeySigner>, LocalSignerError>
pub fn with_private_key_str( self, private_key: impl AsRef<str>, ) -> Result<ClientBuilder<U, D, PrivateKeySigner>, LocalSignerError>
Set the signer from the given private key as a string.
Client::builder().with_private_key_str(
"0x1cee2499e12204c2ed600d780a22a67b3c5fff3310d984cca1f24983d565265c"
).unwrap();Sourcepub fn with_signer<Zi>(
self,
signer: impl Into<Option<Zi>>,
) -> ClientBuilder<U, D, Zi>
pub fn with_signer<Zi>( self, signer: impl Into<Option<Zi>>, ) -> ClientBuilder<U, D, Zi>
Set the signer and wallet.
Sourcepub fn with_timeout(self, tx_timeout: impl Into<Option<Duration>>) -> Self
pub fn with_timeout(self, tx_timeout: impl Into<Option<Duration>>) -> Self
Set the transaction timeout in seconds
Sourcepub fn with_balance_alerts(
self,
config: impl Into<Option<BalanceAlertConfig>>,
) -> Self
pub fn with_balance_alerts( self, config: impl Into<Option<BalanceAlertConfig>>, ) -> Self
Set the balance alerts configuration
Sourcepub fn with_uploader<Z: StorageUploader>(
self,
uploader: Option<Z>,
) -> ClientBuilder<Z, D, S>
pub fn with_uploader<Z: StorageUploader>( self, uploader: Option<Z>, ) -> ClientBuilder<Z, D, S>
Set the storage uploader.
The returned ClientBuilder will be generic over the provider StorageUploader type.
Sourcepub fn with_downloader<Z: StorageDownloader>(
self,
downloader: Z,
) -> ClientBuilder<U, Z, S>
pub fn with_downloader<Z: StorageDownloader>( self, downloader: Z, ) -> ClientBuilder<U, Z, S>
Sets the storage downloader for fetching data from URLs.
Sourcepub async fn with_uploader_config(
self,
config: &StorageUploaderConfig,
) -> Result<ClientBuilder<StandardUploader, D, S>, StorageError>
pub async fn with_uploader_config( self, config: &StorageUploaderConfig, ) -> Result<ClientBuilder<StandardUploader, D, S>, StorageError>
Set the storage uploader from the given config
Sourcepub fn with_price_provider(
self,
price_provider: impl Into<Option<PriceProviderArc>>,
) -> Self
pub fn with_price_provider( self, price_provider: impl Into<Option<PriceProviderArc>>, ) -> Self
Set a custom price provider for fetching market prices.
If provided, the OfferLayer will use market prices (p10 and p99 percentiles)
when OfferParams doesn’t explicitly set min_price or max_price.
This method allows you to use any implementation of PriceProvider, not just IndexerClient.
This is useful for testing with mock providers or using alternative price data sources.
If not set, the indexer URL from the Deployment will be used to create an IndexerClient. The price provider takes precedence over the deployment’s indexer URL.
// Example: Use a custom price provider
// let custom_provider: PriceProviderArc = ...;
// ClientBuilder::new().with_price_provider(Some(custom_provider));Sourcepub fn config_offer_layer(
self,
f: impl FnOnce(&mut OfferLayerConfigBuilder) -> &mut OfferLayerConfigBuilder,
) -> Self
pub fn config_offer_layer( self, f: impl FnOnce(&mut OfferLayerConfigBuilder) -> &mut OfferLayerConfigBuilder, ) -> Self
Modify the OfferLayer configuration used in the StandardRequestBuilder.
use alloy::primitives::utils::parse_units;
ClientBuilder::new().config_offer_layer(|config| config
.max_price_per_cycle(parse_units("0.1", "gwei").unwrap())
.ramp_up_period(36)
.lock_timeout(120)
.timeout(300)
);Sourcepub fn config_request_id_layer(
self,
f: impl FnOnce(&mut RequestIdLayerConfigBuilder) -> &mut RequestIdLayerConfigBuilder,
) -> Self
pub fn config_request_id_layer( self, f: impl FnOnce(&mut RequestIdLayerConfigBuilder) -> &mut RequestIdLayerConfigBuilder, ) -> Self
Modify the RequestIdLayer configuration used in the StandardRequestBuilder.
use boundless_market::request_builder::RequestIdLayerMode;
ClientBuilder::new().config_request_id_layer(|config| config
.mode(RequestIdLayerMode::Nonce)
);Sourcepub fn config_storage_layer(
self,
f: impl FnOnce(&mut StorageLayerConfigBuilder) -> &mut StorageLayerConfigBuilder,
) -> Self
pub fn config_storage_layer( self, f: impl FnOnce(&mut StorageLayerConfigBuilder) -> &mut StorageLayerConfigBuilder, ) -> Self
Modify the StorageLayer configuration used in the StandardRequestBuilder.
ClientBuilder::new().config_storage_layer(|config| config
.inline_input_max_bytes(10240)
);Sourcepub fn config_request_finalizer(
self,
f: impl FnOnce(&mut FinalizerConfigBuilder) -> &mut FinalizerConfigBuilder,
) -> Self
pub fn config_request_finalizer( self, f: impl FnOnce(&mut FinalizerConfigBuilder) -> &mut FinalizerConfigBuilder, ) -> Self
Modify the Finalizer configuration used in the StandardRequestBuilder.
Sourcepub fn with_skip_preflight(self, skip: bool) -> Self
pub fn with_skip_preflight(self, skip: bool) -> Self
Set whether to skip preflight/pricing checks on the request builder.
If true, preflight checks are skipped.
If false, preflight checks are run.
If not called, falls back to checking the BOUNDLESS_IGNORE_PREFLIGHT environment variable.