#[non_exhaustive]pub struct ParameterizationMode { /* private fields */ }Available on non-
target_os=zkvm only.Expand description
Parameterization mode for the request builder.
Defines the proving and executor speeds used to calculate recommended timeouts. Note: setting faster speeds may result in fewer provers being able to fulfill the request, higher prices, and lower fulfillment guarantees.
Implementations
Sourceimpl ParameterizationMode
impl ParameterizationMode
Sourcepub fn fulfillment() -> Self
pub fn fulfillment() -> Self
Creates a parameterization mode for fulfillment.
This mode is more conservative and ensures more provers can fulfill the request.
Sets the ramp up period as 10x the executor time assuming the executor speed is 30 MHz. Sets the lock timeout as the sum of the ramp up period and the proving and executor times assuming the proving speed is 500 kHz and the executor speed is 30 MHz and capped at 4 hours. Sets the timeout as 2 times the lock timeout and capped at 8 hours.